summaryrefslogtreecommitdiffstats
path: root/tools/monitor/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tools/monitor/main.cpp')
-rw-r--r--tools/monitor/main.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/monitor/main.cpp b/tools/monitor/main.cpp
index 194e08c..7f6eb5d 100644
--- a/tools/monitor/main.cpp
+++ b/tools/monitor/main.cpp
@@ -1,5 +1,5 @@
/**
* A monitor application that runs tmwserv-account and tmwserv-game.
* (C) 2009 Thorbjørn Lindeijer
*
* When a server crashes, a gdb process is spawned to create a backtrace,
@@ -217,8 +217,8 @@ private:
int ServerMonitor::sigtermFd[2];
ServerMonitor::ServerMonitor()
- : mAccountServer("src/tmwserv-account")
- , mGameServer("src/tmwserv-game")
+ : mAccountServer("src/manaserv-account")
+ , mGameServer("src/manaserv-game")
{
if (::socketpair(AF_UNIX, SOCK_STREAM, 0, sigtermFd))
qFatal("Couldn't create TERM socketpair");
@@ -1,5 +1,5 @@
/**
- * A monitor application that runs tmwserv-account and tmwserv-game.
+ * A monitor application that runs manaserv-account and manaserv-game.
* (C) 2009 Thorbjørn Lindeijer
*